@@ -1,4 +1,4 @@
-# (C) Copyright 2014 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,14 +12,37 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
+# Copyright (c) 2012, Datadog <info@datadoghq.com>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * Neither the name of the Datadog nor the
+#       names of its contributors may be used to endorse or promote products
+#       derived from this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL DATADOG BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 """Monasca-Statsd is a Python client for Statsd that adds dimensions.
 """
 from monascastatsd.connection import Connection
 from monascastatsd.counter import Counter
 from monascastatsd.gauge import Gauge
-from monascastatsd.histogram import Histogram
-from monascastatsd.set import Set
 from monascastatsd.timer import Timer
 
 
@@ -66,26 +89,6 @@ class Client(object):
                      connection=connection,
                      dimensions=self._update_dimensions(dimensions))
 
-    def get_histogram(self, name=None, connection=None, dimensions=None):
-        """Gets a Histogram object.
-
-        """
-        if connection is None:
-            connection = self.connection
-        return Histogram(name=self._update_name(name),
-                         connection=connection,
-                         dimensions=self._update_dimensions(dimensions))
-
-    def get_set(self, name=None, connection=None, dimensions=None):
-        """Gets a Set object.
-
-        """
-        if connection is None:
-            connection = self.connection
-        return Set(name=self._update_name(name),
-                   connection=connection,
-                   dimensions=self._update_dimensions(dimensions))
-
     def get_timer(self, name=None, connection=None, dimensions=None):
         """Gets a Timer object.
 
