@@ -1,4 +1,4 @@
-# (C) Copyright 2014 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,6 +12,31 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
+# Copyright (c) 2012, Datadog <info@datadoghq.com>
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * Neither the name of the Datadog nor the
+#       names of its contributors may be used to endorse or promote products
+#       derived from this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL DATADOG BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 # -*- coding: utf-8 -*-
 
 """Tests for monascastatsd.py."""
@@ -100,47 +125,41 @@ class TestMonascaStatsd(unittest.TestCase):
                                           dimensions={'date': '10/24', 'time': '23:00'})
 
         counter.increment(dimensions={'country': 'canada', 'color': 'red'})
-        self.assertEqual("counter_with_dims:1|c|#{'date': '10/24', 'color': 'red', " +
-                         "'country': 'canada', 'env': 'test', 'time': '23:00'}",
-                         self.recv(counter))
+
+        result = self.recv(counter)
+        self.assertRegexpMatches(result, "counter_with_dims:1|c|#{")
+        self.assertRegexpMatches(result, "'country': 'canada'")
+        self.assertRegexpMatches(result, "'date': '10/24'")
+        self.assertRegexpMatches(result, "'color': 'red'")
+        self.assertRegexpMatches(result, "'env': 'test'")
+        self.assertRegexpMatches(result, "'time': '23:00'")
 
         counter += 1
-        self.assertEqual("counter_with_dims:1|c|#{'date': '10/24', 'env': 'test', 'time': '23:00'}",
-                         self.recv(counter))
 
-    def test_set(self):
-        set = self.client.get_set('set')
-        set.send('metric', 123)
-        assert self.recv(set) == "set.metric:123|s|#{'env': 'test'}"
+        result = self.recv(counter)
+        self.assertRegexpMatches(result, "counter_with_dims:1|c|#{")
+        self.assertRegexpMatches(result, "'date': '10/24'")
+        self.assertRegexpMatches(result, "'env': 'test'")
+        self.assertRegexpMatches(result, "'time': '23:00'")
 
     def test_gauge(self):
         gauge = self.client.get_gauge('gauge')
         gauge.send('metric', 123.4)
         assert self.recv(gauge) == "gauge.metric:123.4|g|#{'env': 'test'}"
 
-    def test_histogram(self):
-        histogram = self.client.get_histogram('histogram')
-
-        histogram.send('metric', 123.4)
-        self.assertEqual("histogram.metric:123.4|h|#{'env': 'test'}", self.recv(histogram))
-
     def test_gauge_with_dimensions(self):
         gauge = self.client.get_gauge('gauge')
         gauge.send('gt', 123.4,
                    dimensions={'country': 'china',
                                'age': 45,
                                'color': 'blue'})
-        self.assertEqual("gauge.gt:123.4|g|#{" +
-                         "'color': 'blue', " +
-                         "'country': 'china', " +
-                         "'age': 45, " +
-                         "'env': 'test'}",
-                         self.recv(gauge))
 
-    def test_histogram_with_dimensions(self):
-        histogram = self.client.get_histogram('my_hist')
-        histogram.send('h', 1, dimensions={'color': 'red'})
-        self.assertEqual("my_hist.h:1|h|#{'color': 'red', 'env': 'test'}", self.recv(histogram))
+        result = self.recv(gauge)
+        self.assertRegexpMatches(result, "gauge.gt:123.4|g|#{")
+        self.assertRegexpMatches(result, "'country': 'china'")
+        self.assertRegexpMatches(result, "'age': 45")
+        self.assertRegexpMatches(result, "'color': 'blue'")
+        self.assertRegexpMatches(result, "'env': 'test'")
 
     def test_sample_rate(self):
         counter = self.client.get_counter('sampled_counter')
@@ -164,7 +183,7 @@ class TestMonascaStatsd(unittest.TestCase):
     def test_timing(self):
         timer = self.client.get_timer()
         timer.timing('t', 123)
-        self.assertEqual("t:123|ms|#{'env': 'test'}", self.recv(timer))
+        self.assertEqual("t:123|g|#{'env': 'test'}", self.recv(timer))
 
     def test_time(self):
         timer = self.client.get_timer()
@@ -174,7 +193,7 @@ class TestMonascaStatsd(unittest.TestCase):
         name_value, type_, dimensions = packet.split('|')
         name, value = name_value.split(':')
 
-        self.assertEqual('ms', type_)
+        self.assertEqual('g', type_)
         self.assertEqual('t', name)
         self.assert_almost_equal(2.0, float(value), 0.1)
         self.assertEqual("{'env': 'test'}", dimensions.lstrip('#'))
@@ -199,7 +218,7 @@ class TestMonascaStatsd(unittest.TestCase):
         name_value, type_, dimensions = packet.split('|')
         name, value = name_value.split(':')
 
-        self.assertEqual('ms', type_)
+        self.assertEqual('g', type_)
         self.assertEqual('timed.test', name)
         self.assert_almost_equal(0.5, float(value), 0.1)
         self.assertEqual("{'env': 'test'}", dimensions.lstrip('#'))
@@ -218,7 +237,7 @@ class TestMonascaStatsd(unittest.TestCase):
         timer.timing('timer', 123)
         self.client.connection.close_buffer()
 
-        self.assertEqual("site.views:123|g|#{'env': 'test'}\nsite.timer:123|ms|#{'env': 'test'}",
+        self.assertEqual("site.views:123|g|#{'env': 'test'}\nsite.timer:123|g|#{'env': 'test'}",
                          self.recv(gauge))
 
     def test_context_manager(self):
@@ -229,7 +248,7 @@ class TestMonascaStatsd(unittest.TestCase):
             client.get_gauge('page').send('views', 123)
             client.get_timer('page').timing('timer', 12)
 
-        self.assertEqual('ContextTester.page.views:123|g\nContextTester.page.timer:12|ms',
+        self.assertEqual('ContextTester.page.views:123|g\nContextTester.page.timer:12|g',
                          fake_socket.recv())
 
     def test_batched_buffer_autoflush(self):
